pub trait IntoPluginValue {
// Required method
fn into_plugin_value(self) -> PluginValue;
}Expand description
Helper trait for types that can be converted to PluginValue
pub trait IntoPluginValue {
// Required method
fn into_plugin_value(self) -> PluginValue;
}Helper trait for types that can be converted to PluginValue